@@ -3,7 +3,7 @@ import sys
 import winreg
 
 
-SUB_KEY = "Software/Microsoft/Command Processor"
+SUB_KEY = "Software\\Microsoft\\Command Processor"
 HOME_PATH = os.path.expanduser('~')
 
 
